/******************************************************************************
;  *       @型号                 : MC51F7424
;  *       @创建日期             : 2023.02.09
;  *       @公司/作者            : SINOMCU.COM-AE
;  *       @晟矽微官网           : http://www.sinomcu.com/
;  *       @版权                 : 晟矽微电 版权所有.
;  *----------------------摘要描述---------------------------------
;  * ADC外设设置宏定义(寄存器操作及宏函数)                                 
******************************************************************************/

#ifndef __ADC_H
#define __ADC_H

#define ADC_FINISH                0
#define ADC_ONGOING               1

/*ADCCR0*/
#define ADC_CMPEN_POS             0x07
#define ADC_CMPEN_MASK            (0x01 << ADC_CMPEN_POS)
#define ADC_CMPLIF_POS            0x06
#define ADC_CMPLIF_MASK           (0x01 << ADC_CMPLIF_POS)
#define ADC_CMPGIF_POS            0x05
#define ADC_CMPGIF_MASK           (0x01 << ADC_CMPGIF_POS)
#define ADC_IF_POS                0x04
#define ADC_IF_MASK               (0x01 << ADC_IF_POS)
#define ADC_VREF_POS              0x02
#define ADC_VREF_MASK             (0x03 << ADC_VREF_POS)   /*2bit*/
#define ADC_VREF_PIN              (0x00 << ADC_VREF_POS)
#define ADC_VREF_VDD              (0x01 << ADC_VREF_POS)
#define ADC_VREF_LDO1P5           (0x02 << ADC_VREF_POS)
#define ADC_VREF_LDO1P65          (0x03 << ADC_VREF_POS)
#define ADC_EOC_POS               0x01
#define ADC_EOC_MASK              (0x01 << ADC_EOC_POS)
#define ADC_EN_POS                0x00
#define ADC_EN_MASK               (0x01 << ADC_EN_POS)
/*ADCCR0 function*/
#define ADC_Enable_CMP()          (ADCCR0 |= ADC_CMPEN_MASK)
#define ADC_Disable_CMP()         (ADCCR0 &= ~ADC_CMPEN_MASK)
#define Get_ADC_CMPLIF()          ((ADCCR0 & ADC_CMPLIF_MASK)? 1 : 0 )
#define Clear_ADC_CMPLIF()        (ADCCR0 &= ~ADC_CMPLIF_MASK)
#define Get_ADC_CMPGIF()          ((ADCCR0 & ADC_CMPGIF_MASK)? 1 : 0 )
#define Clear_ADC_CMPGIF()        (ADCCR0 &= ~ADC_CMPGIF_MASK)
#define Get_ADC_IF()              ((ADCCR0 & ADC_IF_MASK)? 1 : 0 )
#define Clear_ADC_IF()            (ADCCR0 &= ~ADC_IF_MASK)
#define Clear_ADC_IF()            (ADCCR0 &= ~ADC_IF_MASK)
#define Start_ADC_Convert()       (ADCCR0 |= ADC_EOC_MASK)
#define Get_ADC_ConverState()     ((ADCCR0 & ADC_EOC_MASK)? 1 : 0 )
#define ADC_Enable()              (ADCCR0 |= ADC_EN_MASK)
#define ADC_DisableP()            (ADCCR0 &= ~ADC_EN_MASK)
#define ADC_Vref_Set(Vref_select)           { ADCCR0 &= ~ADC_VREF_MASK; \
                                              ADCCR0 |= Vref_select; }
/*ADCCR1*/
#define ADC_TMPEN_POS             0x07
#define ADC_TMPEN_MASK            (0x01 << ADC_TMPEN_POS)
#define ADC_GAIN_POS              0x05
#define ADC_GAIN_MASK             (0x03 << ADC_GAIN_POS)   /*2bit*/
#define ADC_GAIN_1                (0x00 << ADC_GAIN_POS)
#define ADC_GAIN_0P75             (0x01 << ADC_GAIN_POS)
#define ADC_GAIN_0P5              (0x02 << ADC_GAIN_POS)
#define ADC_GAIN_0P25             (0x03 << ADC_GAIN_POS)
#define ADC_CH_POS                0x00
#define ADC_CH_MASK               (0x0F << ADC_CH_POS)     /*4bit*/
#define ADC_Channel_AN0           (0x00 << ADC_CH_POS)
#define ADC_Channel_AN1           (0x01 << ADC_CH_POS)
#define ADC_Channel_AN2           (0x02 << ADC_CH_POS)
#define ADC_Channel_AN3           (0x03 << ADC_CH_POS)
#define ADC_Channel_AN4           (0x04 << ADC_CH_POS)
#define ADC_Channel_AN5           (0x05 << ADC_CH_POS)
#define ADC_Channel_AN6           (0x06 << ADC_CH_POS)
#define ADC_Channel_AN7           (0x07 << ADC_CH_POS)
#define ADC_Channel_AN8           (0x08 << ADC_CH_POS)
#define ADC_Channel_AN9           (0x09 << ADC_CH_POS)
#define ADC_Channel_AN10          (0x0A << ADC_CH_POS)
#define ADC_Channel_OP0OUT        (0x0B << ADC_CH_POS)
#define ADC_Channel_Tmp           (0x0C << ADC_CH_POS)
#define ADC_Channel_LDO1P5        (0x0D << ADC_CH_POS)
#define ADC_Channel_VREF          (0x0E << ADC_CH_POS)
#define ADC_Channel_GND           (0x0F << ADC_CH_POS)
/*ADCCR1 function*/
#define ADC_Enable_Tmp()          (ADCCR1 |= ADC_TMPEN_MASK)
#define ADC_Disable_Tmp()         (ADCCR1 &= ~ADC_TMPEN_MASK)
#define ADC_Channel_Set(Channel)            { ADCCR1 &= ~ADC_CH_MASK; \
                                              ADCCR1 |= Channel ;}
#define ADC_Gain_Set(Gain_set)              { ADCCR1 &= ~ADC_GAIN_MASK; \
                                              ADCCR1 |= Gain_set; }
#define ADC_Gain_Get()            (ADCCR1 & ADC_GAIN_MASK)
/*ADCCR2*/
#define ADC_CLK_SEL_POS           0x07
#define ADC_CLK_SEL_MASK          (0x01 << ADC_CLK_SEL_POS)
#define ADC_CLK_DIV_POS           0x04
#define ADC_CLK_DIV_MASK          (0x07 << ADC_CLK_DIV_POS)/*3bit*/
#define ADC_CLK_DIV_1             (0x00 << ADC_CLK_DIV_POS)
#define ADC_CLK_DIV_2             (0x01 << ADC_CLK_DIV_POS)
#define ADC_CLK_DIV_4             (0x02 << ADC_CLK_DIV_POS)
#define ADC_CLK_DIV_8             (0x03 << ADC_CLK_DIV_POS)
#define ADC_CLK_DIV_16            (0x04 << ADC_CLK_DIV_POS)
#define ADC_CLK_DIV_32            (0x05 << ADC_CLK_DIV_POS)
#define ADC_CLK_DIV_64            (0x06 << ADC_CLK_DIV_POS)
#define ADC_CLK_DIV_3             (0x07 << ADC_CLK_DIV_POS)
#define ADC_SPS_CLK_POS           0x00
#define ADC_SPS_CLK_MASK          (0x07 << ADC_SPS_CLK_POS)/*3bit*/
#define ADC_SPS_CLK_3             (0x00 << ADC_SPS_CLK_POS)
#define ADC_SPS_CLK_4             (0x01 << ADC_SPS_CLK_POS)
#define ADC_SPS_CLK_8             (0x02 << ADC_SPS_CLK_POS)
#define ADC_SPS_CLK_16            (0x03 << ADC_SPS_CLK_POS)
#define ADC_SPS_CLK_32            (0x04 << ADC_SPS_CLK_POS)
#define ADC_SPS_CLK_64            (0x05 << ADC_SPS_CLK_POS)
#define ADC_SPS_CLK_128           (0x06 << ADC_SPS_CLK_POS)
#define ADC_SPS_CLK_256           (0x07 << ADC_SPS_CLK_POS)

#define ADC_Clk_SysClk()          (ADCCR2 &= ~ADC_CLK_SEL_MASK)
#define ADC_Clk_HIRC48M()         (ADCCR2 |= ADC_CLK_SEL_MASK)
#define ADC_ClkDiv_Set(ClkFiv_set)          { ADCCR2 &= ~ ADC_CLK_DIV_MASK; \
                                              ADCCR2 |= ClkFiv_set; }
#define ADC_SampleClk_Set(SampleClk_set)    { ADCCR2 &= ~ ADC_SPS_CLK_MASK; \
                                              ADCCR2 |= SampleClk_set; }
/*ADCCR3*/
#define ADC_PAC_POS               0x07
#define ADC_PAC_POS_MASK          (0x01 << ADC_PAC_POS)
#define ADC_RightShift_POS        0x05
#define ADC_RightShift_MASK       (0x03 << ADC_RightShift_POS)  /*2bit*/
#define ADC_Result_DIV_1          (0x00 << ADC_RightShift_POS)
#define ADC_Result_DIV_2          (0x01 << ADC_RightShift_POS)
#define ADC_Result_DIV_4          (0x02 << ADC_RightShift_POS)
#define ADC_Result_DIV_8          (0x03 << ADC_RightShift_POS)
#define ADC_ResultACC_POS         0x02
#define ADC_ResultACC_MASK        (0x07 << ADC_ResultACC_POS)   /*3bit*/
#define ADC_ResultACC_1           (0x00 << ADC_ResultACC_POS)
#define ADC_ResultACC_4           (0x01 << ADC_ResultACC_POS)
#define ADC_ResultACC_8           (0x02 << ADC_ResultACC_POS)
#define ADC_ResultACC_16          (0x03 << ADC_ResultACC_POS)
#define ADC_ResultACC_32          (0x04 << ADC_ResultACC_POS)
#define ADC_MODE_POS              0x00
#define ADC_MODE_MASK             (0x03 << ADC_MODE_POS)   /*2bit*/
#define ADC_MODE_12BIT            (0x00 << ADC_MODE_POS)
#define ADC_MODE_10BIT            (0x01 << ADC_MODE_POS)
#define ADC_MODE_8BIT             (0x02 << ADC_MODE_POS)
#define ADC_MODE_6BIT             (0x03 << ADC_MODE_POS)
/*ADCCR3 function*/
#define ADC_Result_Cover()        (ADCCR3 &= ~ADC_PAC_POS_MASK)
#define ADC_Result_Accrual()      (ADCCR3 |= ADC_PAC_POS_MASK)
#define ADC_ResultDiv_Set(ResultDiv_set)    { ADCCR3 &= ~ ADC_RightShift_MASK; \
                                              ADCCR3 |= ResultDiv_set; }
#define ADC_ResultACC_Set(ResultACC_set)    { ADCCR3 &= ~ ADC_ResultACC_MASK; \
                                              ADCCR3 |= ResultACC_set; }                                             
#define ADC_Mode_Set(Mode_set)              { ADCCR3 &= ~ ADC_MODE_MASK; \
                                              ADCCR3 |= Mode_set; } 

/*ADCCR4*/
#define ADC_VrefPin_POS           0x06
#define ADC_VrefPin_MASK          (0x03 << ADC_VrefPin_POS)     /*2bit*/
#define ADC_VrefPin_PIN           (0x00 << ADC_VrefPin_POS)
#define ADC_VrefPin_1P2V          (0x01 << ADC_VrefPin_POS)
#define ADC_VrefPin_2P4V          (0x02 << ADC_VrefPin_POS)
#define ADC_VREF_PIN_POS          0x05
#define ADC_VREF_PIN_MASK         (0x01 << ADC_VREF_PIN_POS)
#define ADC_PWM1_Trig_POS         0x03
#define ADC_PWM1_Trig_MASK        (0x01 << ADC_PWM_Trig_POS)
#define ADC_ExPIN_Trig_POS        0x02
#define ADC_ExPIN_Trig_MASK       (0x01 << ADC_ExPIN_Trig_POS)
#define ADC_Timer_Trig_POS        0x00
#define ADC_Timer_Trig_MASK       (0x03 << ADC_Timer_Trig_POS)  /*2bit*/
#define ADC_Timer0_Trig           (0x00 << ADC_VrefPin_POS)
#define ADC_Timer1_Trig           (0x01 << ADC_VrefPin_POS)
#define ADC_Timer2_Trig           (0x02 << ADC_VrefPin_POS)
/*ADCCR4 function*/
#define ADC_Enable_VrefPin()      (ADCCR4 |= ADC_VREF_PIN_MASK)
#define ADC_Disable_VrefPin()     (ADCCR4 &= ~ADC_VREF_PIN_MASK)
#define ADC_Enable_PWM1Trig()     (ADCCR4 |= ADC_PWM1_Trig_MASK)
#define ADC_Disable_PWM1Trig()    (ADCCR4 &= ~ADC_PWM1_Trig_MASK)
#define ADC_Enable_ExPinTrig()    (ADCCR4 |= ADC_ExPIN_Trig_MASK)
#define ADC_Disable_ExPinTrig()   (ADCCR4 |= ADC_ExPIN_Trig_MASK)
#define ADC_VrefPin_Set(Vrefpin_select)     {ADCCR4 &= ~ADC_VrefPin_MASK; \
                                             ADCCR4 |= Vrefpin_select; }

#define Get_ADC_ADRValue()        ADR

/*ADASCR0*/
#define ADC_ADJSTR_POS            0x07
#define ADC_ADJSTR_MASK           (0x01 << ADC_ADJSTR_POS)
#define ADC_AutoScanCH_POS        0x03
#define ADC_AutoScanCH_MASK       (0x07 << ADC_AutoScanCH_POS)  /*3bit*/
#define ADC_AutoScan_1CH          (0x00 << ADC_AutoScanCH_POS)
#define ADC_AutoScan_2CH          (0x01 << ADC_AutoScanCH_POS)
#define ADC_AutoScan_3CH          (0x02 << ADC_AutoScanCH_POS)
#define ADC_AutoScan_4CH          (0x03 << ADC_AutoScanCH_POS)
#define ADC_AutoScan_5CH          (0x04 << ADC_AutoScanCH_POS)
#define ADC_AutoScan_6CH          (0x05 << ADC_AutoScanCH_POS)
#define ADC_AutoScanState_POS     0x02
#define ADC_AutoScanState_MASK    (0x01 << ADC_AutoScanState_POS)
#define ADC_AutoScanTrig_POS      0x01
#define ADC_AutoScanTrig_MASK     (0x01 << ADC_AutoScanTrig_POS)
#define ADC_AutoScanEn_POS        0x00
#define ADC_AutoScanEn_MASK       (0x01 << ADC_AutoScanEn_POS)
#define ADC_AutoScanXdataAddHigh3Bit_POS         0x00
#define ADC_AutoScanXdataAddHigh3Bit_MASK        (0x07 << ADC_AutoScanXdataAddHigh3Bit_POS)   /*3bit*/
#define ADC_AutoScanXdataNum_POS  0x03
#define ADC_AutoScanXdataNum_MASK (0x1F << ADC_AutoScanXdataNum_POS) /*5bit*/
/*ADASCR0 function*/
#define Start_ADC_Adjust()        (ADASCR0 |= ADC_ADJSTR_MASK)
#define Get_ADC_AdjustState()     ((ADASCR0 & ADC_ADJSTR_MASK)? 1 : 0 )
#define Get_ADC_AutoScanState()   ((ADASCR0 & ADC_AutoScanState_MASK)? 1 : 0 )
#define ADC_Trig_OneConvert()     (ADASCR0 &= ~ADC_AutoScanTrig_MASK)
#define ADC_Trig_OneAutoScan()    (ADASCR0 |=  ADC_AutoScanTrig_MASK)
#define ADC_Enable_AutoScan()     (ADASCR0 |= ADC_AutoScanEn_MASK)
#define ADC_Disable_AutoScan()    (ADASCR0 &= ~ADC_AutoScanEn_MASK)
#define Set_ADCAutoScan_ChNum(ChNum)            { ADASCR0 &= ~ADC_AutoScanCH_MASK; \
                                                  ADASCR0 |= ChNum; }


#define Set_ADCAutoScan_Xdata_Add(address)       { ADASCR1 = address; \
                                                   ADASCR2 &= ~ADC_AutoScanXdataAddHigh3Bit_MASK; \
                                                   ADASCR2 |= ((address >>8) & ADC_AutoScanXdataAddHigh3Bit_MASK); }
#define Set_ADCAutoScan_Xdata_Num(Number)        { ADASCR2 &= ~ADC_AutoScanXdataNum_MASK; \
                                                  ADASCR2 |= (((Number-1) <<ADC_AutoScanXdataNum_POS) & ADC_AutoScanXdataNum_MASK); }
#define Set_ADCAutoScan_CH1(channel)             { ADSEQR0 &= ~0x0F; \
                                                   ADSEQR0 |= (channel & 0x0F); }
#define Set_ADCAutoScan_CH2(channel)             { ADSEQR0 &= ~0xF0; \
                                                   ADSEQR0 |= ((channel<<4) & 0xF0); }
#define Set_ADCAutoScan_CH3(channel)             { ADSEQR1 &= ~0x0F; \
                                                   ADSEQR1 |= (channel & 0x0F); }
#define Set_ADCAutoScan_CH4(channel)             { ADSEQR1 &= ~0xF0; \
                                                   ADSEQR1 |= ((channel<<4) & 0xF0); }
#define Set_ADCAutoScan_CH5(channel)             { ADSEQR2 &= ~0x0F; \
                                                   ADSEQR2 |= (channel & 0x0F); }
#define Set_ADCAutoScan_CH6(channel)             { ADSEQR2 &= ~0xF0; \
                                                   ADSEQR2 |= ((channel<<4) & 0xF0); }

#define ADC_IE_POS           0x06
#define ADC_IE_MASK          (0x01 << ADC_IE_POS)
#define ADC_IE_Enable()      (IE |= ADC_IE_MASK)
#define ADC_IE_Disnable()    (IE |= ADC_IE_MASK)

uint16_t Get_ADCResult_SignalCh(uint8_t channel);
float ADC_GainGet(void);

#endif/* __ADC_H */ 

/******************************** END OF FILE *********************************/
